Documentation
=============

The documentation is divided into different parts. We recommend you to read the *Getting started* chapter to have a good introduction to the engine. After this introductive part the documentation dive into more specific aspects of Renoir.

- [Installation](./installation.md)
- [Getting started](./quickstart.md)
- [Extensions](./extensions.md)
